# 18 Nov 11
# 	R script that reads merged climate/conflict data & estimates regression models
#		variation of base model based on weather/climate data
#
#	This file is in support of the publication:
#		OLoughlin, J., F. Witmer, A. Linke, A. Laing, A Gettelman, and J. Dudhia (2012).
#		Climate variability and conflict risk in East Africa 1990-2009.
#		Proceedings of the National Academy of Sciences.
#
#		PNAS Table S3, cols e-g and Figs S7 e-g and S8 e-g
###############################################

# set output directory
outDir <- "C://Users/XXX/"

# load model analsys functions
source(paste(outDir, "../SharedClimateModelFunctions.R", sep=""))

# load grid-month data & define regression variables for analysis
source(paste(outDir, "../LoadOneDegGridMonthData.R", sep=""))

# hot & dry; cold & wet variables
longData$HotDry <- (longData$TI6 >= 1) * (longData$SPI6 <= -1); sum(longData$HotDry)	# 3069 -> 4450
longData$ColdWet <- (longData$TI6 <= -1) * (longData$SPI6 >= 1); sum(longData$ColdWet)	# 403 -> 243

## models w/ HotDry & ColdWet
extremeVars <- c("HotDry", "ColdWet")
for(extremeVar in extremeVars) {	# extremeVar <- "HotDry"
	glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars, extremeVar)
	countryFE <- myGLM(depVar, glmVars)
	thetaNB <- countryFE$theta		# grab theta from glm.nb()
	gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars, extremeVar)
	gamCntryFE <- myGAM(depVar, gamVars, thetaNB, modelName=extremeVar)
	flush.console()
}


## subset by El Nino months (Jan 1991 = 1, Dec 2009 = 228)
#longData$rowID[10000:10010]
# split rowID field to get numYrs and numGrids
rowSplit <- strsplit(longData$rowID, "\\.")
gridIDs<-sapply(1:length(rowSplit), function(x) rowSplit[[x]][1])
yrMnth<-sapply(1:length(rowSplit), function(x) rowSplit[[x]][2])
longYrs<-trunc(as.numeric(yrMnth)/100)
numYrs <- length(table(longYrs))
numGrids <- max(as.numeric(as.character(gridIDs)))
#http://www.cpc.ncep.noaa.gov/products/analysis_monitoring/ensostuff/ensoyears.shtml
elNinoMnths <- c(5:19, 41:51, 77:89, 137:147, 162:170, 188:193, 222:228)
length(elNinoMnths)	# 72
elNinoRows <- sapply(elNinoMnths, function(x) numGrids*(x-1)+1:numGrids)
elNinoData <- longData[elNinoRows, ]

## model for el Nino months subset [SPI6 less sig, TempIndex similar]
glmVars <- c(paste(depVar, "SpLag_lag1", sep=""), precipVar, tempVar, controlVars)
elNinoFE <- myGLM(depVar, glmVars, dataFr=elNinoData)
thetaNB <- elNinoFE$theta		# grab theta from glm.nb()
gamVars <- c(paste(depVar, "SpLag_lag1", sep=""), paste("s(SPI6, bs=\"",baseSmooth,"\")", sep=""), paste("s(TI6, bs=\"",baseSmooth,"\")", sep=""), controlVars)
gam_elNinoFE <- myGAM(depVar, gamVars, thetaNB, modelName="elNino", dataFr=elNinoData)

