# 29 Nov 2011
# 	R script that reads merged climate/conflict data 
#		calculates log transformations as needed
#		define standard regression variables
#		script intended to be 'sourced'
#
#	This file is in support of the publication:
#		OLoughlin, J., F. Witmer, A. Linke, A. Laing, A Gettelman, and J. Dudhia (2012).
#		Climate variability and conflict risk in East Africa 1990-2009.
#		Proceedings of the National Academy of Sciences.
#
################################################

# set location of longDataMonth.csv
dataDir <- "C://Users/XXX/"

## read data 2x; 1st = get number of variables, 2nd = read rowId properly
allLongData <- read.csv(file=paste(dataDir, "longDataMonth.csv", sep=""), nrows=1)
numVars <- ncol(allLongData)-1
longData <- read.csv(file=paste(dataDir, "longDataMonth.csv", sep=""))
longData$rowID <- sprintf('%3.6f', longData$rowID)	# convert rowID to character
#str(longData)

## log transform some variables
longData$GPWpopLn <- log(longData$GPWpop)			# add GPWpopLn variable 
longData$DistToRdLn <- log(longData$DistToRd)		# add DistToRdLn variable 

## add Grid & Year variables by splitting rowID field
rowSplit <- strsplit(longData$rowID, "\\.")
yrMnth <- sapply(1:length(rowSplit), function(x) rowSplit[[x]][2])
longYrs <- trunc(as.numeric(yrMnth)/100)
#longYrs[80000:80100]
yearNum <- longYrs - min(longYrs) + 1
#summary(yearNum)
gridNum <- as.numeric(sapply(1:length(rowSplit), function(x) rowSplit[[x]][1]))
#summary(gridNum)
longData$Grid <- gridNum							# for clustered std. errors
longData$Year <- yearNum							# for year fixed effects


print(paste("     longData names: "))
print(names(longData))
print(paste("     Number of rows in longData should = 91656, it is:", nrow(longData)))	# 91656 = 402 * 19 * 12
#sum(longData$Events)	# 18119
#max(longData$Events)	# max grid-month violence = 80

## define regression variables
depVar <- "Events"
precipVar <- "SPI6"
tempVar <- "TI6"
controlVars <- c("Ethnologue", "BrdrDistLnKm", "CptlDV", "GPWpopLn", "IMR_lag12", "PR_lag12", "ElectPres", "PctGrassland", "DistToRdLn", "CropPIpct", "VCI_lag6", "Country", "factor(Year)")	# Country & factor(Year) are fixed effects

##### Generalized Additive Models (gam) with spline estimates for climate variables
# http://stat.ethz.ch/R-manual/R-devel/library/mgcv/html/smooth.terms.html
# bs=
# * "tp" thin plate regression is default (typically best MSE, so use this one)
#	"ts" is nearly identical to "tp" but with a ridge penalty (s = shrinkage)
# x	"ds" Duchon splines, execution error
#	"cr" cubic regression, smoother than "tp" (but only for some models!)
#	"cs" shrinkage version of "cs", almost identical to "cr"
#	"cc" cyclic cubic regression, similar to "cr", but with narrower CIs & very diff. for temp
# x	"sos" splines on a sphere, only valid for a sphere
#	"ps" P-splines, has large CIs at extremes
# x	"re" random effects, has nonsense results
# x	"mrf" Markov random fields, execution error

## set spline smooth parameter
#baseSmooth <- "cr"
baseSmooth <- "tp"	# a bit slower than 'cr', but generally lower MSE; the default setting

print("     Defined regression variables:")
print(depVar)
print(paste(precipVar, tempVar, sep=", "))
print(controlVars)
